@@ -69,4 +69,5 @@
      canna-release-key-handler
      canna-reset-handler
      canna-get-candidate-handler
-     canna-set-candidate-index-handler))
+     canna-set-candidate-index-handler
+     nil))
