@@ -378,33 +378,36 @@
 
 (define prime-update-candidate-window
   (lambda (sc id)
-    (if (and
-	 (prime-has-preedit? sc)
-	 (not (prime-context-candidate-window sc))
-	 (or prime-always-show-window?
-	     (> (prime-context-candidate-op-count sc)
-		prime-candidate-op-count)))
-	(begin
-	  (prime-get-candidates!
-	   sc
-	   (prime-make-string sc (prime-context-left-string sc) #t)
-	   (prime-context-last-word sc))
-	  (im-begin-candidate
-	   id (prime-get-nr-candidates sc) 0)
-	  (prime-context-set-candidate-window! sc #t)
-	  ))
-    (if (not (prime-has-preedit? sc))
-	(begin
-	  (prime-context-set-candidate-window! sc #f)
-	  (im-end-candidate id)))
-    (if (prime-context-candidate-window sc)
-	(begin
-	  (prime-get-candidates!
-	   sc
-	   (prime-make-string sc (prime-context-left-string sc) #t)
-	   (prime-context-last-word sc))	  
-	  (im-update-candidate id (prime-context-nth sc))))
-    ))
+    (let ((rkc (prime-context-rk-context sc)))
+      (if (and
+	   (prime-has-preedit? sc)
+	   (not (prime-context-candidate-window sc))
+	   (or prime-always-show-window?
+	       (> (prime-context-candidate-op-count sc)
+		  prime-candidate-op-count)))
+	  (begin
+	    (prime-get-candidates!
+	     sc
+	     (prime-make-string sc (prime-context-left-string sc) #t)
+	     (prime-context-last-word sc))
+	    (im-begin-candidate
+	     id (prime-get-nr-candidates sc) 0)
+	    (prime-context-set-candidate-window! sc #t)
+	    ))
+      (if (not (prime-has-preedit? sc))
+	  (begin
+	    (prime-context-set-candidate-window! sc #f)
+	    (im-end-candidate id)))
+      (if (prime-context-candidate-window sc)
+	  (begin
+	    (prime-get-candidates!
+	     sc
+	     (string-append (prime-make-string sc (prime-context-left-string sc) #t)
+			    (rk-pending rkc))
+	     (prime-context-last-word sc))
+	    (if (prime-context-nth sc)
+		(im-update-candidate id (prime-context-nth sc)))))
+    )))
 
 (define prime-has-preedit?
   (lambda (ac)
@@ -579,7 +582,7 @@
 		sc
 		(cons res
 		      (prime-context-left-string sc)))
-	       (prime-context-set-candidate-window! sc #f) ;FIXME:very duty hack
+	       (prime-context-set-candidate-window! sc #f) ;FIXME:very dirty hack
 	       (if (and prime-preedit-immididate-commit? (prime-context-immediate-commit sc))
 		   (begin 
 		     (im-commit id (prime-make-string sc (prime-context-left-string sc) #t))
