@@ -98,12 +98,6 @@ struct obj
 	    char *data;
 	  }
 	string;
-	struct
-	  {
-	    long dim;
-	    struct obj **data;
-	  }
-	lisp_array;
 	struct
 	  {
 	    FILE *f;
@@ -155,7 +149,7 @@ struct obj
 #define tc_string       13
 /*#define tc_double_array 14*/
 /*#define tc_long_array   15*/
-#define tc_lisp_array   16
+/*#define tc_lisp_array   16*/
 #define tc_c_file       17
 /*#define tc_byte_array   18*/
 #define tc_subr_4 19
@@ -279,8 +273,7 @@ void set_gc_hooks (long type,
 		   LISP (*rel) (LISP),
 		   LISP (*mark) (LISP),
 		   void (*scan) (LISP),
-		   void (*free) (LISP),
-		   long *kind);
+		   void (*free) (LISP));
 LISP gc_relocate (LISP x);
 LISP user_gc (LISP args);
 LISP gc_status (LISP args);
@@ -316,8 +309,6 @@ LISP string_upcase (LISP);
 LISP string_downcase (LISP);
 void init_subrs (void);
 //LISP copy_list_slib (LISP);
-long c_sxhash (LISP, long);
-LISP sxhash (LISP, LISP);
 LISP href (LISP, LISP);
 LISP hset (LISP, LISP, LISP);
 LISP equal (LISP, LISP);
