@@ -329,7 +329,7 @@ im_update_prop_list(LISP id, LISP prop_)
   if(uc)
     uim_schedule_cb(uc, PROP_LIST_UPDATE_CB, NULL, 0, 0);
   
-  if(uc->propstr)
+  if(uc && uc->propstr)
     free(uc->propstr);
       
   uc->propstr = uim_code_conv(prop, uc->conv);
@@ -346,10 +346,13 @@ im_update_prop_label(LISP id, LISP prop_)
   uim_context uc = uim_find_context(get_c_long(id));
   char *prop     = uim_get_c_string(prop_);
     
-  if(uc)
+  if(uc) {
     uim_schedule_cb(uc, PROP_LABEL_UPDATE_CB, NULL, 0, 0);
-  
-  if(uc->proplabelstr)
+  } else {
+    return;
+  }
+
+  if(uc && uc->proplabelstr)
     free(uc->proplabelstr);
   
   uc->proplabelstr = uim_code_conv(prop, uc->conv);
