@@ -38,24 +38,23 @@ uim_ipc_open_command(int old_pid, FILE **read_handler, FILE **write_handler, cha
 
 
 char *
-uim_ipc_send_command(int *pid, FILE *read_handler, FILE *write_handler, char* command, char *str)
+uim_ipc_send_command(int *pid, FILE **read_handler, FILE **write_handler, char* command, char *str)
 {
   char *tmp = strdup("");
   char buf[8192];
 
-  if (read_handler == NULL || write_handler == NULL)
-    *pid = uim_ipc_open_command(*pid, &read_handler, &write_handler, command );
-  
+  if (*read_handler == NULL || *write_handler == NULL) {
+    *pid = uim_ipc_open_command(*pid, read_handler, write_handler, command );
+  }
   if(*pid == 0) {
     free(tmp);
     return NULL;
   }
 
-  fprintf( write_handler, str );
-  
+  fprintf( *write_handler, str );
 
  again:
-  if (fflush(write_handler) != 0) {
+  if (fflush(*write_handler) != 0) {
     switch (errno) {
     case EINTR:
       goto again;
@@ -64,7 +63,7 @@ uim_ipc_send_command(int *pid, FILE *read_handler, FILE *write_handler, char* co
     }
   }
 
-  while (fgets (buf, sizeof(buf), read_handler ) != NULL ) {
+  while (fgets (buf, sizeof(buf), *read_handler ) != NULL ) {
     if(strcmp( buf, "\n" ) == 0)
       break;
 
