@@ -120,11 +120,11 @@ int uim_init();
   uim_prop_label_update(uim_context uc);
   void
   uim_set_prop_list_update_cb(uim_context uc,
-			      void (*update_cb)(void *ptr));
+			      void (*update_cb)(void *ptr, char *str));
 
   void
   uim_set_prop_label_update_cb(uim_context uc,
-			       void (*update_cb)(void *ptr));
+			       void (*update_cb)(void *ptr, char *str));
   void
   uim_prop_activate(uim_context uc, char *str);
   /* mode */
